import 'package:flutter/material.dart';

/// 绘制30s完整心电的背景方格
class GridBackgroundPainterForAll extends CustomPainter {
  final int xGridNums = 750; // 1秒25格，共30秒
  final int yGridNums = 120;

  GridBackgroundPainterForAll();

  @override
  void paint(Canvas canvas, Size size) {
    final gridPaint = Paint()
      ..color = Colors.grey.withOpacity(0.5)
      ..style = PaintingStyle.stroke
      ..strokeWidth = 1.0;

    final double xGridSize = size.width / xGridNums;
    final double yGridSize = xGridSize;

    for (int i = 0; i < xGridNums; i++) {
      final offsetX = i * xGridSize;
      canvas.drawLine(
        Offset(offsetX, 0),
        Offset(offsetX, size.height),
        gridPaint,
      );
    }

    for (int i = 0; i < yGridNums; i++) {
      final offsetY = i * yGridSize;
      canvas.drawLine(
        Offset(0, offsetY),
        Offset(size.width, offsetY),
        gridPaint,
      );
    }

    ///最后一根线往左移半个像素
    canvas.drawLine(
      Offset(size.width - 0.5, 0),
      Offset(size.width - 0.5, size.height),
      gridPaint,
    );

    /// 绘制一根中心线
    final centerLinePaint = Paint()
      ..color = Colors.grey.withOpacity(0.5)
      ..style = PaintingStyle.stroke
      ..strokeWidth = 2.0;
    canvas.drawLine(
      Offset(0, size.height / 2),
      Offset(size.width, size.height / 2),
      centerLinePaint,
    );

    /// 每隔5秒绘制一根竖粗线
    final boldLinePaint = Paint()
      ..color = Colors.grey.withOpacity(0.5)
      ..style = PaintingStyle.stroke
      ..strokeWidth = 2.0;
    for (int i = 0; i < xGridNums; i++) {
      if (i % 125 == 0) {
        final offsetX = i * xGridSize;
        canvas.drawLine(
          Offset(offsetX, 0),
          Offset(offsetX, size.height),
          boldLinePaint,
        );

        /// 绘制文字标识
        final textPainter = TextPainter(
          text: TextSpan(
            text: '${i ~/ 25}秒',
            style: TextStyle(
              height: 1,
              color: const Color.fromARGB(255, 121, 121, 121),
              fontSize: 16,
              background: Paint()..color = Colors.white.withOpacity(0.5),
            ),
          ),
          textDirection: TextDirection.ltr,
        );
        textPainter.layout();
        textPainter.paint(
          canvas,
          Offset(offsetX + 5, size.height - 20),
        );
      }
    }
  }

  @override
  bool shouldRepaint(covariant CustomPainter oldDelegate) {
    return false;
  }
}
